<?xml version="1.0" encoding="utf-8"?>

<xsl:stylesheet
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns="http://www.w3.org/1999/xhtml"
  version="1.0">

<xsl:import href="common.xsl" />

<xsl:output 
  method="xml"
  doctype-public="-//W3C/DTD XHTML 1.0 Strict//EN"
  doctype-system="http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd"
  indent="yes"
  omit-xml-declaration="yes"
  encoding="utf-8"/>

<xsl:param name="id" select="'I1341'"/>
<xsl:key name="indi" match="INDI" use="@ID"/>
<xsl:key name="fam" match="FAM" use="@ID"/>

<xsl:template match="/">
  <xsl:variable name="person" select="key('indi',$id)"/>
  
  <html xml:lang="fr" lang="fr">
    <head>
      <title>
        <xsl:text>Généalogie: </xsl:text>
        <xsl:variable name="title">
          <xsl:apply-templates select="$person/NAME" />
        </xsl:variable>
        <xsl:value-of select="string($title)" />
      </title>
    </head>
    <body>
      <xsl:apply-templates select="$person"/>
    </body>
  </html>
</xsl:template>

<xsl:template match="INDI">
  <!-- Show name and parentage -->
  <h1>
    <xsl:apply-templates select="NAME"/>
  </h1>
  <p><xsl:apply-templates select="SEX"/></p>
  <xsl:call-template name="show-parents"/>
  <hr/>

  <xsl:call-template name="show-events"/>

  <xsl:call-template name="show-partners"/>

  <xsl:if test="NOTE">
    <hr/>
  </xsl:if>

  <!-- Show notes -->

  <xsl:for-each select="NOTE">
    <p class="text"><xsl:apply-templates/></p>
  </xsl:for-each>
</xsl:template>

<xsl:template name="css-style">
  <style type="text/css" href="genealogy.css" />
</xsl:template>

<xsl:template name="show-parents">
  <xsl:variable name="parents" select="key('fam', FAMC/@REF)"/>
  <xsl:variable name="father" select="key('indi', $parents/HUSB/@REF)"/>
  <xsl:variable name="mother" select="key('indi', $parents/WIFE/@REF)"/>

  <p>
    <xsl:if test="$father">
      <span class="label">Père: </span><xsl:apply-templates select="$father/NAME"/>&#xa0;
    </xsl:if>
    <xsl:if test="$mother">
      <span class="label">Mère: </span><xsl:apply-templates select="$mother/NAME"/>&#xa0; 
    </xsl:if>
  </p>
</xsl:template>

<xsl:template name="show-events">
  <xsl:for-each select="*">
    <xsl:sort select="substring(DATE, string-length(DATE) - 3)"/>

    <xsl:variable name="event-name">
      <xsl:apply-templates select="." mode="expand"/>
    </xsl:variable>

    <xsl:if test="string($event-name)">
      <h3><xsl:value-of select="$event-name"/></h3>
      <p>
        <span class="label">Date: </span><xsl:apply-templates
          select="DATE"/><br />
        <xsl:if test="PLAC">
          <span class="label">Lieu : </span><xsl:value-of select="PLAC"/><br/>
        </xsl:if>
      </p>
      <xsl:for-each select="NOTE">
        <p class="text"><xsl:apply-templates/></p>
      </xsl:for-each>
    </xsl:if>
  </xsl:for-each>
</xsl:template>

<xsl:template match="BIRT" mode="expand">Naissance</xsl:template>
<xsl:template match="DEAT" mode="expand">Décès</xsl:template>
<xsl:template match="BURI" mode="expand">Enterrement</xsl:template>
<xsl:template match="BAPM" mode="expand">Baptême</xsl:template>
<xsl:template match="MARR" mode="expand">Mariage</xsl:template>
<xsl:template match="EVEN" mode="expand"><xsl:value-of select="TYPE"/></xsl:template>
<xsl:template match="*" mode="expand"/>

<xsl:template name="show-partners">
  <xsl:variable name="subject" select="."/>
  <xsl:for-each select="FAMS/@REF">
    <xsl:variable name="position" select="position()" />
    <xsl:variable name="partnership" select="key('fam',.)"/>

    <xsl:for-each select="$partnership">
      <xsl:sort select="substring(MARR/DATE, string-length(MARR/DATE) - 3)"/>
      <xsl:variable name="partner" 
        select="key('indi', (HUSB/@REF | WIFE/@REF)[.!=$subject/@ID])"/>

      <xsl:variable name="partner-seq">
        <xsl:choose>
          <xsl:when test="count($subject/FAMS)=1"></xsl:when>
          <xsl:otherwise><xsl:value-of select="$position"/></xsl:otherwise>
        </xsl:choose>
      </xsl:variable>

      <xsl:if test="$partner">
        <h2>Conjoint <xsl:value-of select="$partner-seq"/></h2>
        <p><xsl:apply-templates select="$partner/NAME"/></p>
      </xsl:if>

      <xsl:call-template name="show-events"/>

      <xsl:if test="CHIL">
        <p><span class="label">Enfants:</span><br/>
          <xsl:for-each select="CHIL/@REF">
            <xsl:for-each select="key('indi',.)">
              <xsl:sort select="substring(BIRT/DATE, string-length(BIRT/DATE) - 3)"/>
              <xsl:value-of select="substring(BIRT/DATE, string-length(BIRT/DATE) - 3)"/>
              <xsl:text> </xsl:text>
              <xsl:apply-templates select="NAME"/><br/>
            </xsl:for-each>
          </xsl:for-each>
        </p>
      </xsl:if>
    </xsl:for-each>
  </xsl:for-each>
</xsl:template>

<xsl:template match="SEX">
  <xsl:choose>
    <xsl:when test=".='M'">
      <xsl:text>Homme</xsl:text>
    </xsl:when>
    <xsl:when test=".='F'">
      <xsl:text>Femme</xsl:text>
    </xsl:when>
  </xsl:choose>
</xsl:template>

<xsl:template name="month">
  <xsl:param name="name" />

  <xsl:choose>
    <xsl:when test="$name='JAN'">01</xsl:when>
    <xsl:when test="$name='FEB'">02</xsl:when>
    <xsl:when test="$name='MAR'">03</xsl:when>
    <xsl:when test="$name='APR'">04</xsl:when>
    <xsl:when test="$name='MAY'">05</xsl:when>
    <xsl:when test="$name='JUN'">06</xsl:when>
    <xsl:when test="$name='JUL'">07</xsl:when>
    <xsl:when test="$name='AUG'">08</xsl:when>
    <xsl:when test="$name='SEP'">09</xsl:when>
    <xsl:when test="$name='OCT'">10</xsl:when>
    <xsl:when test="$name='NOV'">11</xsl:when>
    <xsl:when test="$name='DEC'">12</xsl:when>
  </xsl:choose>
</xsl:template>

<xsl:template name="showDate">
  <xsl:param name="date" />

  <xsl:choose>
    <xsl:when test="not(contains($date,' '))">
      <xsl:value-of select="$date" />
    </xsl:when>
    <xsl:when test="not(contains(substring-after($date,' '),' '))">
      <xsl:call-template name="month">
        <xsl:with-param name="name" select="substring-before($date,' ')" />
      </xsl:call-template>
      <xsl:text>/</xsl:text>
      <xsl:value-of select="substring-after($date,' ')" />
    </xsl:when>
    <xsl:otherwise>
      <xsl:value-of select="substring-before($date,' ')" />
      <xsl:text>/</xsl:text>
      <xsl:call-template name="month">
        <xsl:with-param name="name"
          select="substring-before(substring-after($date,' '),' ')" />
      </xsl:call-template>
      <xsl:text>/</xsl:text>
      <xsl:value-of select="substring-after(substring-after($date,' '),' ')" />
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="DATE">
  <xsl:choose>
    <xsl:when test="starts-with(.,'ABT ')">
      <xsl:text>~ </xsl:text>
      <xsl:call-template name="showDate">
        <xsl:with-param name="date" select="substring-after(.,' ')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="starts-with(.,'BEF ')">
      <xsl:text>&lt; </xsl:text>
      <xsl:call-template name="showDate">
        <xsl:with-param name="date" select="substring-after(.,' ')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="starts-with(.,'AFT ')">
      <xsl:text>> </xsl:text>
      <xsl:call-template name="showDate">
        <xsl:with-param name="date" select="substring-after(.,' ')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:when test="starts-with(.,'BET ')">
      <xsl:call-template name="showDate">
        <xsl:with-param name="date"
          select="substring-after(substring-before(.,' AND '),' ')"/>
      </xsl:call-template>
      <xsl:text> &lt; . &lt; </xsl:text>
      <xsl:call-template name="showDate">
        <xsl:with-param name="date" select="substring-after(.,' AND ')"/>
      </xsl:call-template>
    </xsl:when>
    <xsl:otherwise>
      <xsl:call-template name="showDate">
        <xsl:with-param name="date" select="."/>
      </xsl:call-template>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>


</xsl:stylesheet>
